DocumentChangeEvent class

Event fired when a document's content changes.

Constructors

DocumentChangeEvent({required String uri, required List<DocumentContentChange> changes})
const

Properties

changes List<DocumentContentChange>
List of content changes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
The document URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited