LumideDebugScope class

A variable scope for a stack frame.

Constructors

LumideDebugScope({required int id, required String name, String? presentationHint, int? namedVariables, int? indexedVariables})
const
LumideDebugScope.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
indexedVariables int?
final
name String
final
namedVariables int?
final
presentationHint String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited