LumideLaunch class abstract

Launch provider bridge for run/debug/test actions owned by the IDE.

Constructors

LumideLaunch()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didEnd(LumideLaunchEvent event) Future<void>
Announces that a launch process ended.
didStart(LumideLaunchEvent event) Future<void>
Announces that a launch process started.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConfigure(Future<LumideLaunchConfiguration?> callback(LumideLaunchConfigureRequest request)) → void
Handles host requests to create or edit configurations.
onDidEnd(void callback(LumideLaunchEvent event)) → void
Observes launch end events from the host.
onDidStart(void callback(LumideLaunchEvent event)) → void
Observes launch start events from the host.
onImportConfiguration(Future<LumideLaunchImportResult> callback(LumideForeignLaunchConfiguration source)) → void
Handles conversion from a foreign launch format into a native source.
onLaunch(Future<void> callback(LumideLaunchRequest request)) → void
Handles host launch requests.
onResolveConfiguration(Future<LumideLaunchResolution> callback(LumideLaunchSourceConfiguration source)) → void
Handles one persisted workspace configuration owned by this provider.
onResolveConfigurations(Future<List<LumideLaunchConfiguration>> callback(LumideLaunchResolveRequest request)) → void
Handles host requests to resolve configurations.
registerProvider({required String id, required String title, List<String> workspacePatterns = const [], List<LumideLaunchKind> kinds = const [LumideLaunchKind.run], List<LumideLaunchKind> defaultKinds = const [LumideLaunchKind.run], String? icon, String? iconPath, String? configurationSchema, List<Map<String, Object?>> configurationSnippets = const [], List<LumideLaunchImportDescriptor> configurationImports = const [], int priority = 0}) Future<void>
Registers a launch provider.
toString() String
A string representation of this object.
inherited
unregisterProvider(String id) Future<void>
Removes a launch provider and all configurations owned by it.
updateConfigurations(String providerId, List<LumideLaunchConfiguration> configurations) Future<void>
Publishes the current launch configurations for providerId.

Operators

operator ==(Object other) bool
The equality operator.
inherited