LumideLaunchResolveRequest class

Request sent when the host asks a provider to refresh configurations.

Constructors

LumideLaunchResolveRequest({required String providerId, LumideLaunchKind? kind, String? workspaceUri})
const
LumideLaunchResolveRequest.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind LumideLaunchKind?
final
providerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceUri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited