LumideRow class
- Inheritance
-
- Object
- LumideWidget
- LumideRow
Constructors
-
LumideRow({String? key, List<
LumideWidget> children = const [], String? mainAxisAlignment, String? crossAxisAlignment, double? spacing}) -
const
-
LumideRow.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
children
→ List<
LumideWidget> -
final
- crossAxisAlignment → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
Optional unique key for widget identification.
finalinherited
- mainAxisAlignment → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this widget to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited