LumideWebviewPanel class abstract

A webview panel.

Constructors

LumideWebviewPanel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes the webview panel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDidReceiveMessage(void callback(Object message)) → void
Registers a callback for messages received from the webview.
postMessage(Object message) Future<void>
Posts a message to the webview.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited