LumideWidget class sealed

Base class for serializable UI widgets.

All SDUI widgets extend this class and can be serialized to JSON for transmission to the host IDE.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
Optional unique key for widget identification.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this widget to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) LumideWidget
Deserializes a widget from JSON.