Permission class sealed
A permission that a plugin requests.
- Implementers
Constructors
- Permission.fileSystem(String path)
-
File system access permission.
constfactory
- Permission.network(String domain)
-
Network access permission.
constfactory
- Permission.shell(String command)
-
Shell command execution permission.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited