DoubleLaunchValue class
A double-typed launch value.
- Inheritance
-
- Object
- LumideLaunchValue<
double> - DoubleLaunchValue
Constructors
- DoubleLaunchValue(double? value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- raw → Object?
-
The untyped value for serialization.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ConfigPropertyType
-
The category type for the IDE UI rendering.
no setteroverride
- value → double?
-
The concrete type-safe value.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited