LumideCommands class abstract
Command registration API.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerCommand(
{required String id, required String title, String? category, required Future< void> callback([Map<String, dynamic> ? args])}) → Future<void> - Registers a command that can be invoked from the Command Palette.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited