LumideFileSystem class abstract
File system operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDirectory(
String path, {bool recursive = false}) → Future< void> - Creates a directory.
-
downloadFile(
String url, String destination, {String? label, bool extract = false}) → Future< void> -
Downloads a file from
urltodestination. -
exists(
String path) → Future< bool> - Checks if a path exists.
-
isDirectory(
String path) → Future< bool> - Checks if a path is a directory.
-
list(
String path) → Future< List< String> > - Lists directory contents.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readString(
String path) → Future< String> - Reads a file as a string.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeString(
String path, String content) → Future< void> - Writes a string to a file.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited