LumideLaunchRequest class
Request sent when the host starts a launch action.
Constructors
- LumideLaunchRequest({required String providerId, required LumideLaunchKind kind, required LumideLaunchConfiguration configuration, bool revealOutput = true})
-
const
- LumideLaunchRequest.fromJson(Map json)
-
factory
Properties
- configuration → LumideLaunchConfiguration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → LumideLaunchKind
-
final
- providerId → String
-
final
- revealOutput → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited