LumideWidget class sealed
Base class for serializable UI widgets.
All SDUI widgets extend this class and can be serialized to JSON for transmission to the host IDE.
- Implementers
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this widget to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → LumideWidget - Deserializes a widget from JSON.